@@ -1,4 +1,3 @@
-/* $Id: gucharmap-charmap.c 1376 2007-12-03 21:42:48Z chpe $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -14,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
  */
 
 #include "config.h"
@@ -30,7 +29,6 @@
 #include "gucharmap-intl.h"
 #include "gucharmap-marshal.h"
 #include "gucharmap-settings.h"
-#include "chartable_accessible.h"
 
 gboolean _gucharmap_unicode_has_nameslist_entry (gunichar uc);
 
@@ -68,7 +66,7 @@ gucharmap_charmap_class_init (GucharmapCharmapClass *clazz)
       g_signal_new ("status-message", gucharmap_charmap_get_type (), 
                     G_SIGNAL_RUN_FIRST,
                     G_STRUCT_OFFSET (GucharmapCharmapClass, status_message),
-                    NULL, NULL, _gucharmap_marshal_VOID__STRING, G_TYPE_NONE, 
+                    NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE,
                     1, G_TYPE_STRING);
 
   gucharmap_charmap_signals[LINK_CLICKED] =
@@ -298,7 +296,7 @@ set_details (GucharmapCharmap *charmap,
   gunichar2 *utf16;
 
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (charmap->details));
-  gtk_text_buffer_set_text (buffer, "", -1);
+  gtk_text_buffer_set_text (buffer, "", 0);
 
   gtk_text_buffer_get_start_iter (buffer, &iter);
   gtk_text_buffer_place_cursor (buffer, &iter);
@@ -499,7 +497,8 @@ active_char_set (GtkWidget        *widget,
   const gchar **temps;
   gint i;
 
-  set_details (charmap, wc);
+  if (charmap->showing_details_page)
+    set_details (charmap, wc);
 
   g_idle_add (gucharmap_active_char_save, GUINT_TO_POINTER(wc));
 
@@ -767,9 +766,27 @@ make_details_page (GucharmapCharmap *charmap)
   return scrolled_window;
 }
 
+static void
+notebook_switch_page (GtkNotebook *notebook,
+                      GtkNotebookPage *page /* useless */,
+                      guint page_num,
+                      GucharmapCharmap *charmap)
+{
+  charmap->showing_details_page = (page_num == 1);
+
+  if (charmap->showing_details_page)
+    set_details (charmap, gucharmap_table_get_active_character (charmap->chartable));
+  else
+    {
+      GtkTextBuffer *buffer;
+
+      buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (charmap->details));
+      gtk_text_buffer_set_text (buffer, "", 0);
+    }
+}
+
 static GtkWidget *
-make_chartable_pane (GucharmapCharmap       *charmap,
-                     GucharmapCodepointList *codepoint_list)
+make_chartable_pane (GucharmapCharmap *charmap)
 {
   GtkWidget *notebook;
 
@@ -777,7 +794,6 @@ make_chartable_pane (GucharmapCharmap       *charmap,
   gtk_widget_show (notebook);
 
   charmap->chartable = GUCHARMAP_TABLE (gucharmap_table_new ());
-  gucharmap_table_set_codepoint_list (charmap->chartable, codepoint_list);
 
   gtk_widget_show (GTK_WIDGET (charmap->chartable));
   g_signal_connect (G_OBJECT (charmap->chartable), "set-active-char", 
@@ -812,7 +828,6 @@ gucharmap_charmap_new (GucharmapChapters *chapters)
 {
   GucharmapCharmap *charmap = g_object_new (gucharmap_charmap_get_type (), NULL);
   GtkWidget *pane2;
-  gunichar last_char;
 
   charmap->hand_cursor = gdk_cursor_new (GDK_HAND2);
   charmap->regular_cursor = gdk_cursor_new (GDK_XTERM);
@@ -821,49 +836,18 @@ gucharmap_charmap_new (GucharmapChapters *chapters)
 
   g_signal_connect (G_OBJECT (chapters), "changed", G_CALLBACK (chapter_changed), charmap);
 
-  pane2 = make_chartable_pane (charmap, gucharmap_chapters_get_codepoint_list (GUCHARMAP_CHAPTERS (chapters)));
+  pane2 = make_chartable_pane (charmap);
   gtk_paned_pack1 (GTK_PANED (charmap), GTK_WIDGET (chapters), FALSE, TRUE);
   gtk_paned_pack2 (GTK_PANED (charmap), pane2, TRUE, TRUE);
+  g_signal_connect (pane2, "switch-page",
+                    G_CALLBACK (notebook_switch_page), charmap);
 
-  set_details (charmap, gucharmap_table_get_active_character (charmap->chartable));
-
-  last_char = gucharmap_settings_get_last_char ();
-  /* not validating characters allows restoration of unassigned characters */
-  if (last_char < UNICHAR_MAX && last_char > 0)
-    gucharmap_charmap_go_to_character (charmap, last_char);
+  gucharmap_charmap_go_to_character (charmap, gucharmap_settings_get_last_char ());
 
   return GTK_WIDGET (charmap);
 }
 
-GType
-gucharmap_charmap_get_type (void)
-{
-  static GType gucharmap_charmap_type = 0;
-
-  if (!gucharmap_charmap_type)
-    {
-      static const GTypeInfo gucharmap_charmap_info =
-      {
-        sizeof (GucharmapCharmapClass),
-        NULL,           /* base_init */
-        NULL,           /* base_finalize */
-        (GClassInitFunc) gucharmap_charmap_class_init,
-        NULL,           /* class_finalize */
-        NULL,           /* class_data */
-        sizeof (GucharmapCharmap),
-        0,              /* n_preallocs */
-        (GInstanceInitFunc) gucharmap_charmap_init
-      };
-
-      gucharmap_charmap_type = g_type_register_static (GTK_TYPE_HPANED, 
-                                                       "GucharmapCharmap", 
-                                                       &gucharmap_charmap_info,
-                                                       0);
-    }
-
-  return gucharmap_charmap_type;
-}
-
+G_DEFINE_TYPE (GucharmapCharmap, gucharmap_charmap, GTK_TYPE_HPANED)
 
 void 
 gucharmap_charmap_set_font (GucharmapCharmap *charmap, 
@@ -899,9 +883,11 @@ gucharmap_charmap_set_chapters (GucharmapCharmap  *charmap,
 {
   gtk_container_remove (GTK_CONTAINER (charmap), GTK_PANED (charmap)->child1);
   gtk_paned_pack1 (GTK_PANED (charmap), GTK_WIDGET (chapters), FALSE, TRUE);
-  gucharmap_table_set_codepoint_list (charmap->chartable, gucharmap_chapters_get_codepoint_list (chapters));
   g_signal_connect (G_OBJECT (chapters), "changed", G_CALLBACK (chapter_changed), charmap);
   gtk_widget_show (GTK_WIDGET (chapters));
+
+  /* Keep the same character selected as before */
+  gucharmap_charmap_go_to_character (charmap, gucharmap_table_get_active_character (charmap->chartable));
 }
 
 GucharmapChapters *
