@@ -1,4 +1,3 @@
-/* $Id: gucharmap-charmap.h 710 2004-02-02 00:03:49Z nlevitt $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -14,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
  */
 
 #ifndef GUCHARMAP_CHARMAP_H
@@ -47,8 +46,8 @@ struct _GucharmapCharmap
 
   GucharmapTable *chartable;
 
-  /* rows and columns on a page */
-  gint rows, cols;
+  gint _unused_1;
+  gboolean showing_details_page;
 
   GtkWidget *details;  /* GtkTextView * */
 
@@ -73,9 +72,7 @@ GType                 gucharmap_charmap_get_type           (void);
 GtkWidget *           gucharmap_charmap_new                (GucharmapChapters *chapters);
 void                  gucharmap_charmap_set_font           (GucharmapCharmap  *charmap, 
                                                             const gchar       *font_name);
-void                  gucharmap_charmap_identify_clipboard (GucharmapCharmap  *charmap, 
-                                                            GtkClipboard      *clipboard);
-void                  gucharmap_charmap_go_to_character    (GucharmapCharmap  *charmap, 
+void                  gucharmap_charmap_go_to_character    (GucharmapCharmap  *charmap,
                                                             gunichar           uc);
 GucharmapTable *      gucharmap_charmap_get_chartable      (GucharmapCharmap  *charmap);
 void                  gucharmap_charmap_set_chapters       (GucharmapCharmap  *charmap,
