@@ -1,5 +1,3 @@
-/* $Id: gucharmap-intl.h,v 1.3 2006/02/12 00:07:14 behdad Exp $ */
-
 #ifndef GUCHARMAP_INTL_H
 #define GUCHARMAP_INTL_H
 
@@ -7,7 +5,7 @@
 
 G_BEGIN_DECLS
 
-void gucharmap_intl_ensure_initialized (void);
+void _gucharmap_intl_ensure_initialized (void);
 
 G_END_DECLS
 
